@@ -1,3 +1,10 @@
+#!/usr/bin/perl
+
+my @months = qw( Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec );
+my @days = qw(Sun Mon Tue Wed Thu Fri Sat Sun);
+($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime();
+my $dtstr = sprintf("%s, %d %s %d %02d:%02d:%02d", $days[$wday], $mday, $months[$mon], $year+1900, $hour, $min, $sec);
+
 my $repo = "https://qgvdial.googlecode.com/svn/trunk";
 my $cmd;
 
@@ -30,31 +37,33 @@ $basedir = "$basedir/qgvdial-$qver";
 system("rm -rf qgvdial-* qgvtp-* qgvdial_* qgvtp_*");
 
 system("svn export $repo $basedir");
-system("cp $basedir/icons/64/qgvdial.png $basedir/src/qgvdial.png");
 
 # Append the version to the pro file
-open(PRO_FILE, ">>$basedir/src/src.pro") || die "Cannot open pro file";
+open(PRO_FILE, ">>$basedir/qgvdial/maemo/maemo.pro") || die "Cannot open pro file";
 print PRO_FILE "VERSION=__QGVDIAL_VERSION__\n";
 close PRO_FILE;
 
 # Version replacement
-$cmd = "perl $basedir/build-files/version.pl __QGVDIAL_VERSION__ $qver $basedir";
+$cmd = "perl version.pl __QGVDIAL_VERSION__ $qver $basedir";
 print "$cmd\n";
 system($cmd);
 
-# Copy the correct pro file
-system("cp $basedir/build-files/qgvdial/maemo/pro.qgvdial $basedir/qgvdial.pro");
+# Date replacement
+$cmd = "perl version.pl __CHANGELOG_DATETIME__ '$dtstr' $basedir";
+print "$cmd\n";
+system($cmd);
 
 # Do everything upto the preparation of the debian directory. Code is still not compiled.
-$cmd = "cd $basedir && echo y | dh_make --createorig --single -e yuvraaj\@gmail.com -c lgpl";
+$cmd = "cd $basedir && echo y | dh_make -n --createorig --single -e yuvraaj\@gmail.com -c lgpl2";
 print "$cmd\n";
 system($cmd);
 
 # Put all the debianization files into the debian folder
-system("cd $basedir/build-files/qgvdial/maemo ; mv postinst prerm control rules $basedir/debian/");
+system("cd $basedir/qgvdial/maemo/qtc_packaging/debian_fremantle/ ; cp compat control copyright README rules ../../../../debian/");
+system("cd $basedir/debian ; cp ../build-files/qgvdial/changelog.txt changelog");
 
-# Fix the changelog and put it into the correct location
-system("head -1 $basedir/debian/changelog >dest.txt && cat $basedir/build-files/qgvdial/changelog >>dest.txt && tail -2 $basedir/debian/changelog | sed 's/unknown/Yuvraaj Kelkar/g' >>dest.txt && mv dest.txt $basedir/debian/changelog");
+# Copy the top level pro file
+system("cp $basedir/build-files/qgvdial/maemo/maemo.pro $basedir");
 
 # Reverse the order of these two lines for a complete build 
 $cmd = "cd $basedir && dpkg-buildpackage -rfakeroot";
@@ -62,7 +71,7 @@ $cmd = "cd $basedir && dpkg-buildpackage -rfakeroot -sa -S -uc -us";
 # Execute the rest of the build command
 system($cmd);
 
-system("dput -f fremantle-upload qgvdial*.changes");
+system("cd $basedir/.. ; dput -f fremantle-upload qgvdial*.changes");
 
 exit(0);
 
