@@ -1,3 +1,10 @@
+#!/usr/bin/perl
+
+my @months = qw( Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec );
+my @days = qw(Sun Mon Tue Wed Thu Fri Sat Sun);
+($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime();
+my $dtstr = sprintf("%s, %d %s %d %02d:%02d:%02d", $days[$wday], $mday, $months[$mon], $year+1900, $hour, $min, $sec);
+
 my $repo = "https://qgvdial.googlecode.com/svn/trunk";
 my $cmd;
 
@@ -30,35 +37,47 @@ $basedir = "$basedir/qgvdial-$qver";
 system("rm -rf qgvdial-* qgvtp-* qgvdial_* qgvtp_*");
 
 $cmd = "svn export $repo $basedir";
+print "$cmd\n";
 system($cmd);
-system("cp $basedir/icons/qgv.png $basedir/src/qgvdial.png");
 
 # Append the version to the pro file
-open(PRO_FILE, ">>$basedir/src/src.pro") || die "Cannot open pro file";
+open(PRO_FILE, ">>$basedir/qgvdial/qt-not-qml/desktop_linux.pro") || die "Cannot open pro file";
 print PRO_FILE "VERSION=__QGVDIAL_VERSION__\n";
 close PRO_FILE;
 
 # Version replacement
-$cmd = "perl $basedir/build-files/version.pl __QGVDIAL_VERSION__ $qver $basedir";
+$cmd = "perl version.pl __QGVDIAL_VERSION__ $qver $basedir";
 print "$cmd\n";
 system($cmd);
 
-# Copy the correct pro file
-system("cp $basedir/build-files/qgvdial/pro.qgvdial $basedir/qgvdial.pro");
+# Date replacement
+$cmd = "perl version.pl __CHANGELOG_DATETIME__ '$dtstr' $basedir";
+print "$cmd\n";
+system($cmd);
 
 # Do everything upto the preparation of the debian directory. Code is still not compiled.
-$cmd = "cd $basedir && echo y | dh_make --createorig --single -e yuvraaj\@gmail.com -c lgpl";
+$cmd = "mv $basedir/qgvdial/qt-not-qml $basedir/qgvdial/qgvdial-$qver";
+print "$cmd\n";
+system($cmd);
+$cmd = "cd $basedir/qgvdial/qgvdial-$qver && echo y | dh_make --createorig --single -e yuvraaj\@gmail.com -c lgpl";
 print "$cmd\n";
 system($cmd);
 
 # Put all the debianization files into the debian folder
-system("cd $basedir/build-files/qgvdial/ubuntu ; mv postinst prerm control rules $basedir/debian/");
-
-# Fix the changelog and put it into the correct location
-system("head -1 $basedir/debian/changelog >dest.txt && cat $basedir/build-files/qgvdial/changelog >>dest.txt && tail -2 $basedir/debian/changelog | sed 's/unknown/Yuvraaj Kelkar/g' >>dest.txt && mv dest.txt $basedir/debian/changelog");
+$cmd = "cd $basedir/build-files/qgvdial/ubuntu ; mv postinst prerm control rules changelog $basedir/qgvdial/qgvdial-$qver/debian/";
+print "$cmd\n";
+system("$cmd");
+$cmd = "cd $basedir/build-files/qgvdial ; cp changelog.txt $basedir/qgvdial/qgvdial-$qver/debian/changelog";
+print "$cmd\n";
+system("$cmd");
 
 # Built it all!
-$cmd = "cd $basedir && dpkg-buildpackage -rfakeroot -nc -uc -us";
+$cmd = "cd $basedir/qgvdial/qgvdial-$qver && dpkg-buildpackage -rfakeroot -nc -uc -us";
+print "$cmd\n";
+system($cmd);
+
+$cmd = "cp $basedir/qgvdial/qgvdial*deb .";
+print "$cmd\n";
 system($cmd);
 
 exit(0);
